@@ -6,6 +6,7 @@ from sqlalchemy.sql.expression import and_, Select
 from sqlalchemy.types import DATE, TIME, DATETIME, INTEGER, NUMERIC, \
     BOOLEAN, BIGINT
 from neptuno.dataset import DataSet
+from types import NoneType
 
 class Busqueda(object):
     
@@ -506,7 +507,7 @@ def search(session, table_name, q=None, rp=100, offset=0, show_ids=False,
                                       ),
                      ).correlate(tbl)
         
-        if str(sql) != '':
+        if not isinstance(sql, NoneType): #str(sql) != '':
             sql = and_(sql, exists(sel))
             
         else:
@@ -514,15 +515,15 @@ def search(session, table_name, q=None, rp=100, offset=0, show_ids=False,
             
     # where
     if isinstance(tbl, Select):
-        if str(sql) != '':
-            qry = tbl.where(sql)
+        if not isinstance(sql, NoneType):
+            qry = tbl.where(and_(sql, True))
 
         else:
             qry = tbl.where(True)
             
     else:
         qry = tbl.select(whereclause=sql)
-
+        
     # order by
     if order:
         qry = qry.order_by(order)
